@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
 
 #include <QCoreApplication>
 #include <QDebug>
@@ -300,17 +278,17 @@ void Project::writeProFile()
     if (m_subdirs.isEmpty()) {
         ts << "TEMPLATE = app\n";
         ts << "TARGET = " << QFileInfo(m_outputFileName).baseName() << "\n";
-        for (const FileClass &fc : qAsConst(m_fileClasses))
+        for (const FileClass &fc : std::as_const(m_fileClasses))
             fc.writeProBlock(ts);
         ts << "\nPATHS *=";
-        for (const QDir dir : qAsConst(m_items))
+        for (const QDir dir : std::as_const(m_items))
             ts << " \\\n    " << dir.path();
         ts << "\n\nDEPENDPATH *= $$PATHS\n";
         ts << "\nINCLUDEPATH *= $$PATHS\n";
     } else {
         ts << "TEMPLATE = subdirs\n";
         ts << "SUBDIRS = ";
-        for (const QString &subdir : qAsConst(m_subdirs))
+        for (const QString &subdir : std::as_const(m_subdirs))
             ts << " \\\n    " << subdir;
         ts << "\n";
     }
